@@ -8,13 +8,13 @@ function laptop_mode_enable {
     
     for x in /sys/bus/ide/devices/*/block; do 
 	drive=$(basename $(readlink $x));
-	$HDPARM -S 12 /dev/$drive 2>/dev/null
+	$HDPARM -S $SPINDOWN_TIME /dev/$drive 2>/dev/null
 	$HDPARM -B 1 /dev/$drive 2>/dev/null
     done
     
     for x in /sys/bus/scsi/devices/*/block; do 
 	drive=$(basename $(readlink $x));
-	$HDPARM -S 12 /dev/$drive 2>/dev/null
+	$HDPARM -S $SPINDOWN_TIME /dev/$drive 2>/dev/null
 	$HDPARM -B 1 /dev/$drive 2>/dev/null
     done
 }
