@@ -1,6 +1,6 @@
 #!/bin/bash
 
-BRIGHTNESS=$(cat /proc/acpi/sony/brightness)
+BRIGHTNESS=$(cat /sys/class/backlight/sony/actual_brightness)
 
 if [ "$BRIGHTNESS" -gt 8 ]; then
 	BRIGHTNESS=1
@@ -9,7 +9,7 @@ fi
 if [ "x$1" = "xdown" ]; then
    if [ "x$BRIGHTNESS" != "x1" ]; then
       BRIGHTNESS=$(( $BRIGHTNESS - 1 ))
-      echo $BRIGHTNESS > /proc/acpi/sony/brightness
+      echo $BRIGHTNESS > /sys/class/backlight/sony/brightness
    else
       [ -x /usr/bin/spicctrl ] && /usr/bin/spicctrl -b 0   
    fi
@@ -18,7 +18,7 @@ if [ "x$1" = "xdown" ]; then
 elif [ "x$1" = "xup" ]; then
    if [ "x$BRIGHTNESS" != "x8" ]; then
       BRIGHTNESS=$(( $BRIGHTNESS + 1 ))
-      echo $BRIGHTNESS > /proc/acpi/sony/brightness
+      echo $BRIGHTNESS > /sys/class/backlight/sony/brightness
    fi
    [ -x /usr/bin/smartdimmer ] && smartdimmer -i 2>/dev/null
 else
